@@ -123,9 +123,7 @@ calendar_window_create_calendar (CalendarWindow *calwin)
 	struct tm                  tm1;
 
 	calendar = gtk_calendar_new ();
-	#if GTK_CHECK_VERSION (3, 0, 0)
-	gtk_widget_set_size_request(GTK_WIDGET(calendar), 260, 100);
-	#endif
+	gtk_widget_set_size_request(GTK_WIDGET(calendar), 330, 100);
 	options = gtk_calendar_get_display_options (GTK_CALENDAR (calendar));
 	if (calwin->priv->show_weeks)
 		options |= GTK_CALENDAR_SHOW_WEEK_NUMBERS;
@@ -185,32 +183,19 @@ create_hig_frame (CalendarWindow *calwin,
                   GCallback   callback)
 {
         GtkWidget *vbox;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        GtkWidget *alignment;
-#endif
         GtkWidget *label;
         GtkWidget *hbox;
-        GtkWidget *button;
         char      *bold_title;
-	char      *text;
         GtkWidget *expander;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-        vbox = gtk_vbox_new (FALSE, 6);
-#endif
 
         bold_title = g_strdup_printf ("<b>%s</b>", title);
 	expander = gtk_expander_new (bold_title);
         g_free (bold_title);
 	gtk_expander_set_use_markup (GTK_EXPANDER (expander), TRUE);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-	hbox = gtk_hbox_new (FALSE, 0);
-#endif
 
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (hbox), expander, FALSE, FALSE, 0);
@@ -228,26 +213,31 @@ create_hig_frame (CalendarWindow *calwin,
 	g_signal_connect (hbox, "add", G_CALLBACK (add_child), expander);
 
         if (button_label) {
+                GtkWidget *button_box;
+                GtkWidget *button;
+                gchar *text;
+
+                button_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+                gtk_widget_show (button_box);
+
                 button = gtk_button_new ();
+                gtk_container_add (GTK_CONTAINER (button_box), button);
+
                 text = g_markup_printf_escaped ("<small>%s</small>", button_label);
                 label = gtk_label_new (text);
                 g_free (text);
                 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
                 gtk_container_add (GTK_CONTAINER (button), label);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
                 gtk_widget_show_all (button);
 
-                gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-#else
-                alignment = gtk_alignment_new (1, 0, 0, 0);
-                gtk_container_add (GTK_CONTAINER (alignment), button);
-                gtk_widget_show_all (alignment);
-
-                gtk_container_add (GTK_CONTAINER (hbox), alignment);
-#endif
+                gtk_box_pack_end (GTK_BOX (hbox), button_box, FALSE, FALSE, 0);
 
                 g_signal_connect_swapped (button, "clicked", callback, calwin);
+
+                g_object_bind_property (expander, "expanded",
+                                        button_box, "visible",
+                                        G_BINDING_DEFAULT|G_BINDING_SYNC_CREATE);
         }
 
 	g_settings_bind (calwin->priv->settings, key, expander, "expanded",
@@ -290,11 +280,7 @@ calendar_window_fill (CalendarWindow *calwin)
         gtk_container_add (GTK_CONTAINER (calwin), frame);
         gtk_widget_show (frame);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-        vbox = gtk_vbox_new (FALSE, 6);
-#endif
 
         gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
         gtk_container_add (GTK_CONTAINER (frame), vbox);
@@ -495,6 +481,7 @@ calendar_window_init (CalendarWindow *calwin)
 	gtk_window_set_type_hint (window, GDK_WINDOW_TYPE_HINT_DOCK);
 	gtk_window_set_decorated (window, FALSE);
 	gtk_window_set_resizable (window, FALSE);
+	gtk_window_set_default_size (window, 337, -1);
 	gtk_window_stick (window);
 	gtk_window_set_title (window, _("Calendar"));
 	gtk_window_set_icon_name (window, CLOCK_ICON);
