@@ -288,6 +288,7 @@ clock_location_tile_fill (ClockLocationTile *this)
         gtk_box_pack_start (GTK_BOX (head_section), priv->city_label, FALSE, FALSE, 0);
 
         priv->time_label = gtk_label_new (NULL);
+        gtk_label_set_width_chars (GTK_LABEL (priv->time_label), 20);
         gtk_widget_set_margin_end (priv->time_label, 3);
 #if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (priv->time_label), 0.0);
@@ -309,6 +310,7 @@ clock_location_tile_fill (ClockLocationTile *this)
         priv->current_label = gtk_label_new ("");
         gtk_widget_show (priv->current_label);
         gtk_widget_set_no_show_all (priv->current_button, TRUE);
+        gtk_widget_set_valign (priv->current_button, GTK_ALIGN_CENTER);
         gtk_container_add (GTK_CONTAINER (priv->current_button), priv->current_label);
         gtk_widget_set_tooltip_text (priv->current_button,
                                      _("Set location as current location and use its timezone for this computer"));
@@ -316,6 +318,7 @@ clock_location_tile_fill (ClockLocationTile *this)
         priv->current_marker = gtk_image_new_from_icon_name ("go-home", GTK_ICON_SIZE_BUTTON);
         gtk_widget_set_halign (priv->current_marker, GTK_ALIGN_END);
         gtk_widget_set_valign (priv->current_marker, GTK_ALIGN_CENTER);
+        gtk_widget_set_margin_start (priv->current_marker, 75);
         gtk_widget_set_no_show_all (priv->current_marker, TRUE);
 
         priv->current_spacer = gtk_event_box_new ();
@@ -323,13 +326,10 @@ clock_location_tile_fill (ClockLocationTile *this)
 
         strut = gtk_event_box_new ();
         gtk_box_pack_start (GTK_BOX (box), strut, TRUE, TRUE, 0);
-        gtk_box_pack_start (GTK_BOX (box), priv->current_button, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (box), priv->current_marker, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (box), priv->current_spacer, FALSE, FALSE, 0);
         priv->button_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
-        gtk_size_group_set_ignore_hidden (priv->button_group, FALSE);
         gtk_size_group_add_widget (priv->button_group, strut);
-        gtk_size_group_add_widget (priv->button_group, priv->current_button);
 
         /*
          * Avoid resizing the popup as the tiles display the current marker,
@@ -341,8 +341,6 @@ clock_location_tile_fill (ClockLocationTile *this)
          * but they are never visible together).
          */
         priv->current_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
-        gtk_size_group_set_ignore_hidden (priv->current_group, FALSE);
-        gtk_size_group_add_widget (priv->current_group, priv->current_button);
         gtk_size_group_add_widget (priv->current_group, priv->current_marker);
         gtk_size_group_add_widget (priv->current_group, priv->current_spacer);
 
@@ -358,6 +356,7 @@ clock_location_tile_fill (ClockLocationTile *this)
 
         gtk_box_pack_start (GTK_BOX (tile), priv->clock_face, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (tile), head_section, TRUE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX (tile), priv->current_button, FALSE, FALSE, 0);
 
         gtk_container_add (GTK_CONTAINER (priv->box), tile);
         gtk_container_add (GTK_CONTAINER (this), priv->box);
