@@ -4,7 +4,6 @@
 
 #include <cairo.h>
 #include <sys/time.h>
-#include <sys/timeb.h>
 #include <gtk/gtk.h>
 #include <math.h>
 
@@ -33,7 +32,7 @@ static char *marker_files[MARKER_NB] = {
         ICONDIR "/clock-map-location-current.png"
 };
 
-static guint signals[LAST_SIGNAL];
+static guint signals[LAST_SIGNAL] = { 0 };
 
 typedef struct {
         time_t last_refresh;
@@ -58,7 +57,6 @@ typedef struct {
 static void clock_map_finalize (GObject *);
 static void clock_map_size_allocate (GtkWidget *this,
 					 GtkAllocation *allocation);
-#if GTK_CHECK_VERSION (3, 0, 0)
 static gboolean clock_map_draw (GtkWidget *this,
 				      cairo_t *cr);
 static void clock_map_get_preferred_width (GtkWidget *widget,
@@ -67,12 +65,6 @@ static void clock_map_get_preferred_width (GtkWidget *widget,
 static void clock_map_get_preferred_height (GtkWidget *widget,
 					    gint *minimum_height,
 					    gint *natural_height);
-#else
-static gboolean clock_map_expose (GtkWidget *this,
-				      GdkEventExpose *expose);
-static void clock_map_size_request (GtkWidget *this,
-				    GtkRequisition *requisition);
-#endif
 static void clock_map_place_locations (ClockMap *this);
 static void clock_map_render_shadow (ClockMap *this);
 static void clock_map_display (ClockMap *this);
@@ -100,14 +92,9 @@ clock_map_class_init (ClockMapClass *this_class)
         /* GtkWidget signals */
 
         widget_class->size_allocate = clock_map_size_allocate;
-#if GTK_CHECK_VERSION (3, 0, 0)
         widget_class->draw = clock_map_draw;
 	widget_class->get_preferred_width = clock_map_get_preferred_width;
 	widget_class->get_preferred_height = clock_map_get_preferred_height;
-#else
-        widget_class->expose_event = clock_map_expose;
-        widget_class->size_request = clock_map_size_request;
-#endif
 
         g_type_class_add_private (this_class, sizeof (ClockMapPrivate));
 
@@ -234,94 +221,40 @@ clock_map_refresh (ClockMap *this)
 }
 
 static gboolean
-#if GTK_CHECK_VERSION (3, 0, 0)
 clock_map_draw (GtkWidget *this, cairo_t *cr)
-#else
-clock_map_expose (GtkWidget *this, GdkEventExpose *event)
-#endif
 {
         ClockMapPrivate *priv = PRIVATE (this);
-	GtkStyle *style;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	int width, height;
-#else
-	GdkWindow *window;
-	GtkAllocation allocation;
-	GdkRectangle region;
-        cairo_t *cr;
-#endif
+	GtkStyleContext *context;
+	GdkRGBA color;
 
-	style = gtk_widget_get_style (this);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	window = gtk_widget_get_window (this);
-	gtk_widget_get_allocation (this, &allocation);
-#endif
+	context = gtk_widget_get_style_context (this);
+	gtk_style_context_get_color (context, GTK_STATE_FLAG_ACTIVE, &color);
 
 	if (!priv->shadow_map_pixbuf) {
                 g_warning ("Needed to refresh the map in expose event.");
 		clock_map_refresh (CLOCK_MAP (this));
         }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	width = gdk_pixbuf_get_width (priv->shadow_map_pixbuf);
 	height = gdk_pixbuf_get_height (priv->shadow_map_pixbuf);
 
 	gdk_cairo_set_source_pixbuf (cr, priv->shadow_map_pixbuf, 0, 0);
 	cairo_rectangle (cr, 0, 0, width, height);
 	cairo_paint (cr);
-#else
-        cr = gdk_cairo_create (window);
-
-	region.x = allocation.x;
-	region.y = allocation.y;
-	region.width = gdk_pixbuf_get_width (priv->shadow_map_pixbuf);
-	region.height = gdk_pixbuf_get_height (priv->shadow_map_pixbuf);
-
-	gdk_rectangle_intersect (&region, &(event->area), &region);
-	gdk_draw_pixbuf (window,
-			 style->black_gc,
-			 priv->shadow_map_pixbuf,
-			 region.x - allocation.x,
-			 region.y - allocation.y,
-			 region.x,
-			 region.y,
-			 region.width,
-			 region.height,
-			 GDK_RGB_DITHER_NORMAL,
-			 0, 0);
-#endif
 
         /* draw a simple outline */
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cairo_rectangle (cr, 0.5, 0.5, width - 1, height - 1);
-	gdk_cairo_set_source_color (cr, &style->mid [GTK_STATE_ACTIVE]);
-#else
-        cairo_rectangle (
-                cr,
-                allocation.x + 0.5, allocation.y + 0.5,
-                gdk_pixbuf_get_width (priv->shadow_map_pixbuf) - 1,
-                gdk_pixbuf_get_height (priv->shadow_map_pixbuf) - 1);
-
-        cairo_set_source_rgb (
-                cr,
-                style->mid [GTK_STATE_ACTIVE].red   / 65535.0,
-                style->mid [GTK_STATE_ACTIVE].green / 65535.0,
-                style->mid [GTK_STATE_ACTIVE].blue  / 65535.0);
-#endif
+	gdk_cairo_set_source_rgba (cr, &color);
 
         cairo_set_line_width (cr, 1.0);
         cairo_stroke (cr);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        cairo_destroy (cr);
-#endif
-
 	return FALSE;
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void
-clock_map_get_preferred_width (GtkWidget *widget,
+clock_map_get_preferred_width (GtkWidget *this,
                                 gint *minimum_width,
                                 gint *natural_width)
 {
@@ -329,20 +262,12 @@ clock_map_get_preferred_width (GtkWidget *widget,
 }
 
 static void
-clock_map_get_preferred_height (GtkWidget *widget,
+clock_map_get_preferred_height (GtkWidget *this,
                                  gint *minimum_height,
                                  gint *natural_height)
 {
         *minimum_height = *natural_height = 125;
 }
-#else
-static void
-clock_map_size_request (GtkWidget *this, GtkRequisition *requisition)
-{
-        requisition->width = 250;
-        requisition->height = 125;
-}
-#endif
 
 static void
 clock_map_size_allocate (GtkWidget *this, GtkAllocation *allocation)
@@ -662,7 +587,8 @@ clock_map_display (ClockMap *this)
 {
         ClockMapPrivate *priv = PRIVATE (this);
 
-        clock_map_render_shadow (this);
+        if (priv->width > 0 || priv->height > 0)
+                clock_map_render_shadow (this);
 	gtk_widget_queue_draw (GTK_WIDGET (this));
 
         time (&priv->last_refresh);
