@@ -63,6 +63,7 @@ static void call_system_monitor(GtkAction* action, TasklistData* tasklist);
 static void display_properties_dialog(GtkAction* action, TasklistData* tasklist);
 static void display_help_dialog(GtkAction* action, TasklistData* tasklist);
 static void display_about_dialog(GtkAction* action, TasklistData* tasklist);
+static void destroy_tasklist(GtkWidget* widget, TasklistData* tasklist);
 
 static void tasklist_update(TasklistData* tasklist)
 {
@@ -119,27 +120,17 @@ static void applet_change_orient(MatePanelApplet* applet, MatePanelAppletOrient
 
 	tasklist->orientation = new_orient;
 
-#ifdef WNCK_CHECK_VERSION
 #if WNCK_CHECK_VERSION (3, 4, 6)
 	wnck_tasklist_set_orientation (WNCK_TASKLIST (tasklist->tasklist), new_orient);
-#endif
 #endif
 	tasklist_update(tasklist);
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void applet_change_background(MatePanelApplet* applet, MatePanelAppletBackgroundType type, GdkColor* color, cairo_pattern_t* pattern, TasklistData* tasklist)
-#else
-static void applet_change_background(MatePanelApplet* applet, MatePanelAppletBackgroundType type, GdkColor* color, GdkPixmap* pixmap, TasklistData* tasklist)
-#endif
 {
 	switch (type)
 	{
 		case PANEL_NO_BACKGROUND:
-#if !GTK_CHECK_VERSION (3, 0 ,0)
-			wnck_tasklist_set_button_relief(WNCK_TASKLIST(tasklist->tasklist), GTK_RELIEF_NORMAL);
-			break;
-#endif
 		case PANEL_COLOR_BACKGROUND:
 		case PANEL_PIXMAP_BACKGROUND:
 			wnck_tasklist_set_button_relief(WNCK_TASKLIST(tasklist->tasklist), GTK_RELIEF_NONE);
@@ -157,16 +148,6 @@ static void applet_change_pixel_size(MatePanelApplet* applet, gint size, Tasklis
 	tasklist_update(tasklist);
 }
 
-static void destroy_tasklist(GtkWidget* widget, TasklistData* tasklist)
-{
-	g_object_unref(tasklist->settings);
-
-	if (tasklist->properties_dialog)
-		gtk_widget_destroy(tasklist->properties_dialog);
-
-	g_free(tasklist);
-}
-
 /* TODO: this is sad, should be used a function to retrieve  applications from
  *  .desktop or some like that. */
 static const char* system_monitors[] = {
@@ -398,26 +379,23 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 	GtkCssProvider  *provider;
 	GdkScreen *screen;
 #endif
-
 	tasklist = g_new0(TasklistData, 1);
 
 	tasklist->applet = GTK_WIDGET(applet);
-
 #if GTK_CHECK_VERSION (3, 20, 0)
 	provider = gtk_css_provider_new ();
 	screen = gdk_screen_get_default ();
 	gtk_css_provider_load_from_data (provider,
-	                                 ".mate-panel-menu-bar button,\n"
-	                                 " #tasklist-button {\n"
-	                                 " padding: 0px;\n"
-	                                 " margin: 0px;\n }",
-	                                 -1, NULL);
+										".mate-panel-menu-bar button,\n"
+										" #tasklist-button {\n"
+										" padding: 0px;\n"
+										" margin: 0px;\n }",
+										-1, NULL);
 	gtk_style_context_add_provider_for_screen (screen,
-	                                GTK_STYLE_PROVIDER (provider),
-	                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+										GTK_STYLE_PROVIDER (provider),
+										GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	g_object_unref (provider);
 #endif
-
 	mate_panel_applet_set_flags(MATE_PANEL_APPLET(tasklist->applet), MATE_PANEL_APPLET_EXPAND_MAJOR | MATE_PANEL_APPLET_EXPAND_MINOR | MATE_PANEL_APPLET_HAS_HANDLE);
 
 	setup_gsettings(tasklist);
@@ -443,21 +421,11 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 			break;
 	}
 
-#ifdef WNCK_CHECK_VERSION
-#if WNCK_CHECK_VERSION (3, 0, 0)
 	tasklist->tasklist = wnck_tasklist_new();
-#else
-	tasklist->tasklist = wnck_tasklist_new(NULL);
-#endif
-#else
-	tasklist->tasklist = wnck_tasklist_new(NULL);
-#endif
 
-#ifdef WNCK_CHECK_VERSION
 #if WNCK_CHECK_VERSION (3, 4, 6)
 	wnck_tasklist_set_orientation (WNCK_TASKLIST (tasklist->tasklist), tasklist->orientation);
 	wnck_tasklist_set_middle_click_close (WNCK_TASKLIST (tasklist->tasklist), TRUE);
-#endif
 #endif
 
 	wnck_tasklist_set_icon_loader(WNCK_TASKLIST(tasklist->tasklist), icon_loader_func, tasklist, NULL);
@@ -570,7 +538,7 @@ static void display_about_dialog(GtkAction* action, TasklistData* tasklist)
 	};
 
 	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
+		"Copyright \xc2\xa9 2012-2017 MATE developers\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
 		"Copyright \xc2\xa9 2002 Red Hat, Inc.";
 
@@ -717,3 +685,18 @@ static void display_properties_dialog(GtkAction* action, TasklistData* tasklist)
 	gtk_window_set_screen(GTK_WINDOW(tasklist->properties_dialog), gtk_widget_get_screen(tasklist->applet));
 	gtk_window_present(GTK_WINDOW(tasklist->properties_dialog));
 }
+
+static void destroy_tasklist(GtkWidget* widget, TasklistData* tasklist)
+{
+	g_signal_handlers_disconnect_by_data (G_OBJECT (tasklist->applet), tasklist);
+
+	g_signal_handlers_disconnect_by_data (tasklist->settings, tasklist);
+
+	g_object_unref(tasklist->settings);
+
+	if (tasklist->properties_dialog)
+		gtk_widget_destroy(tasklist->properties_dialog);
+
+	g_free(tasklist);
+
+}
