@@ -86,6 +86,7 @@ typedef struct {
 static void display_properties_dialog(GtkAction* action, PagerData* pager);
 static void display_help_dialog(GtkAction* action, PagerData* pager);
 static void display_about_dialog(GtkAction* action, PagerData* pager);
+static void destroy_pager(GtkWidget* widget, PagerData* pager);
 
 static void pager_update(PagerData* pager)
 {
@@ -131,16 +132,11 @@ static void update_properties_for_wm(PagerData* pager)
 			g_assert_not_reached();
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	if (pager->properties_dialog) {
 	        gtk_widget_hide (pager->properties_dialog);
 	        gtk_widget_unrealize (pager->properties_dialog);
 	        gtk_widget_show (pager->properties_dialog);
 	}
-#else
-	if (pager->properties_dialog)
-		gtk_window_reshow_with_initial_size(GTK_WINDOW(pager->properties_dialog));
-#endif
 }
 
 static void window_manager_changed(WnckScreen* screen, PagerData* pager)
@@ -203,7 +199,6 @@ static void applet_change_orient(MatePanelApplet* applet, MatePanelAppletOrient
 		gtk_label_set_text(GTK_LABEL(pager->label_row_col), pager->orientation == GTK_ORIENTATION_HORIZONTAL ? _("rows") : _("columns"));
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void applet_change_background(MatePanelApplet* applet, MatePanelAppletBackgroundType type, GdkColor* color, cairo_pattern_t *pattern, PagerData* pager)
 {
         GtkStyleContext *new_context;
@@ -214,41 +209,11 @@ static void applet_change_background(MatePanelApplet* applet, MatePanelAppletBac
 
         wnck_pager_set_shadow_type (WNCK_PAGER (pager->pager),
                 type == PANEL_NO_BACKGROUND ? GTK_SHADOW_NONE : GTK_SHADOW_IN);
-#else
-static void applet_change_background(MatePanelApplet* applet, MatePanelAppletBackgroundType type, GdkColor* color, GdkPixmap* pixmap, PagerData* pager)
-{
-        /* taken from the TrashApplet */
-        GtkRcStyle *rc_style;
-        GtkStyle *style;
-
-        /* reset style */
-        gtk_widget_set_style (GTK_WIDGET (pager->pager), NULL);
-        rc_style = gtk_rc_style_new ();
-        gtk_widget_modify_style (GTK_WIDGET (pager->pager), rc_style);
-        g_object_unref (rc_style);
-
-	switch (type)
-	{
-                case PANEL_COLOR_BACKGROUND:
-                        gtk_widget_modify_bg (GTK_WIDGET (pager->pager), GTK_STATE_NORMAL, color);
-                        break;
-
-                case PANEL_PIXMAP_BACKGROUND:
-                        style = gtk_style_copy (gtk_widget_get_style (GTK_WIDGET (pager->pager)));
-                        if (style->bg_pixmap[GTK_STATE_NORMAL])
-                                g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-                        style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref(pixmap);
-                        gtk_widget_set_style (GTK_WIDGET (pager->pager), style);
-                        g_object_unref (style);
-                        break;
-
-                case PANEL_NO_BACKGROUND:
-                default:
-                        break;
-	}
-#endif
 }
 
+/* Replacement for the default scroll handler that also cares about the wrapping property.
+ * Alternative: Add behaviour to libwnck (to the WnckPager widget).
+ */
 static gboolean applet_scroll(MatePanelApplet* applet, GdkEventScroll* event, PagerData* pager)
 {
 	GdkScrollDirection absolute_direction;
@@ -260,10 +225,8 @@ static gboolean applet_scroll(MatePanelApplet* applet, GdkEventScroll* event, Pa
 	if (event->type != GDK_SCROLL)
 		return FALSE;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	if (event->direction == GDK_SCROLL_SMOOTH)
 		return FALSE;
-#endif
 
 	index = wnck_workspace_get_number(wnck_screen_get_active_workspace(pager->screen));
 	n_workspaces = wnck_screen_get_workspace_count(pager->screen);
@@ -357,16 +320,6 @@ static gboolean applet_scroll(MatePanelApplet* applet, GdkEventScroll* event, Pa
 	return TRUE;
 }
 
-static void destroy_pager(GtkWidget* widget, PagerData* pager)
-{
-	g_object_unref (pager->settings);
-
-	if (pager->properties_dialog)
-		gtk_widget_destroy(pager->properties_dialog);
-
-	g_free(pager);
-}
-
 static const GtkActionEntry pager_menu_actions[] = {
 	{
 		"PagerPreferences",
@@ -504,9 +457,7 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 	GtkActionGroup* action_group;
 	gchar* ui_path;
 	gboolean display_names;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkCssProvider *provider;
-#endif
 
 	pager = g_new0(PagerData, 1);
 
@@ -548,20 +499,11 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 			break;
 	}
 
-#ifdef WNCK_CHECK_VERSION
-#if WNCK_CHECK_VERSION (3, 0, 0)
 	pager->pager = wnck_pager_new();
-#else
-	pager->pager = wnck_pager_new(NULL);
-#endif
-#else
-	pager->pager = wnck_pager_new(NULL);
-#endif
 	pager->screen = NULL;
 	pager->wm = PAGER_WM_UNKNOWN;
 	wnck_pager_set_shadow_type(WNCK_PAGER(pager->pager), GTK_SHADOW_IN);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkStyleContext *context;
 	context = gtk_widget_get_style_context (GTK_WIDGET (applet));
 	gtk_style_context_add_class (context, "wnck-applet");
@@ -577,13 +519,11 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 					GTK_STYLE_PROVIDER (provider),
 					GTK_STYLE_PROVIDER_PRIORITY_FALLBACK);
 	g_object_unref (provider);
-#endif
+
 	g_signal_connect(G_OBJECT(pager->pager), "destroy", G_CALLBACK(destroy_pager), pager);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	/* overwrite default WnckPager widget scroll-event */
 	g_signal_connect(G_OBJECT(pager->pager), "scroll-event", G_CALLBACK(applet_scroll), pager);
-#endif
 
 	gtk_container_add(GTK_CONTAINER(pager->applet), pager->pager);
 	gtk_widget_show(pager->pager);
@@ -591,9 +531,6 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 	g_signal_connect(G_OBJECT(pager->applet), "realize", G_CALLBACK(applet_realized), pager);
 	g_signal_connect(G_OBJECT(pager->applet), "unrealize", G_CALLBACK(applet_unrealized), pager);
 	g_signal_connect(G_OBJECT(pager->applet), "change_orient", G_CALLBACK(applet_change_orient), pager);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	g_signal_connect(G_OBJECT(pager->applet), "scroll-event", G_CALLBACK(applet_scroll), pager);
-#endif
 	g_signal_connect(G_OBJECT(pager->applet), "change_background", G_CALLBACK(applet_change_background), pager);
 
 	gtk_widget_show(pager->applet);
@@ -643,7 +580,7 @@ static void display_about_dialog(GtkAction* action, PagerData* pager)
 	};
 
 	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
+		"Copyright \xc2\xa9 2012-2017 MATE developers\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
 		"Copyright \xc2\xa9 2002 Red Hat, Inc.";
 
@@ -733,13 +670,6 @@ static void workspace_destroyed(WnckScreen* screen, WnckWorkspace* space, PagerD
 
 static void num_workspaces_value_changed(GtkSpinButton* button, PagerData* pager)
 {
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	/* Slow down a bit after the first change, since it's moving really to
-	 * fast. See bug #336731 for background.
-	 * FIXME: remove this if bug 410520 gets fixed. */
-	button->timer_step = 0.2;
-#endif
-
 	wnck_screen_change_workspace_count(pager->screen, gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pager->num_workspaces_spin)));
 }
 
@@ -813,10 +743,8 @@ static void close_dialog(GtkWidget* button, gpointer data)
 {
 	PagerData* pager = data;
 	GtkTreeViewColumn* col;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkCellArea *area;
 	GtkCellEditable *edit_widget;
-#endif
 
 	/* This is a hack. The "editable" signal for GtkCellRenderer is emitted
 	only on button press or focus cycle. Hence when the user changes the
@@ -827,15 +755,10 @@ static void close_dialog(GtkWidget* button, gpointer data)
 
 	col = gtk_tree_view_get_column(GTK_TREE_VIEW(pager->workspaces_tree), 0);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	area = gtk_cell_layout_get_area (GTK_CELL_LAYOUT (col));
 	edit_widget = gtk_cell_area_get_edit_widget (area);
 	if (edit_widget)
 		gtk_cell_editable_editing_done (edit_widget);
-#else
-	if (col->editable_widget != NULL && GTK_IS_CELL_EDITABLE(col->editable_widget))
-		gtk_cell_editable_editing_done(col->editable_widget);
-#endif
 
 	gtk_widget_destroy(pager->properties_dialog);
 }
@@ -1035,3 +958,14 @@ static void display_properties_dialog(GtkAction* action, PagerData* pager)
 	gtk_window_set_screen(GTK_WINDOW(pager->properties_dialog), gtk_widget_get_screen(pager->applet));
 	gtk_window_present(GTK_WINDOW(pager->properties_dialog));
 }
+
+static void destroy_pager(GtkWidget* widget, PagerData* pager)
+{
+	g_signal_handlers_disconnect_by_data (pager->settings, pager);
+
+	g_object_unref (pager->settings);
+
+	if (pager->properties_dialog)
+		gtk_widget_destroy(pager->properties_dialog);
+	g_free(pager);
+}
