@@ -242,9 +242,14 @@ applet_callback_callback (GtkWidget      *widget,
 	switch (menu->info->type) {
 	case PANEL_OBJECT_LAUNCHER:
 		if (!strcmp (menu->name, "launch"))
-			launcher_launch (menu->info->data, widget);
+			launcher_launch (menu->info->data, NULL);
 		else if (!strcmp (menu->name, "properties"))
 			launcher_properties (menu->info->data);
+		else if (g_str_has_prefix (menu->name, "launch-action_")) {
+			const gchar *action;
+			action = menu->name + (sizeof("launch-action_") - 1);
+			launcher_launch (menu->info->data, action);
+		}
 		break;
 	case PANEL_OBJECT_DRAWER:
 		if (strcmp (menu->name, "add") == 0) {
@@ -329,7 +334,7 @@ mate_panel_applet_get_callback (GList      *user_menu,
 void
 mate_panel_applet_add_callback (AppletInfo          *info,
 			   const char          *callback_name,
-			   const char          *stock_item,
+			   const char          *icon_name,
 			   const char          *menuitem_text,
 			   CallbackEnabledFunc  is_enabled_func)
 {
@@ -341,7 +346,7 @@ mate_panel_applet_add_callback (AppletInfo          *info,
 
 	menu                  = g_new0 (AppletUserMenu, 1);
 	menu->name            = g_strdup (callback_name);
-	menu->stock_item      = g_strdup (stock_item);
+	menu->gicon           = panel_gicon_from_icon_name (icon_name);
 	menu->text            = g_strdup (menuitem_text);
 	menu->is_enabled_func = is_enabled_func;
 	menu->sensitive       = TRUE;
@@ -354,6 +359,24 @@ mate_panel_applet_add_callback (AppletInfo          *info,
 	mate_panel_applet_recreate_menu (info);
 }
 
+void
+mate_panel_applet_clear_user_menu (AppletInfo *info)
+{
+	GList *l;
+
+	for (l = info->user_menu; l != NULL; l = l->next) {
+		AppletUserMenu *umenu = l->data;
+
+		g_free (umenu->name);
+		g_clear_object (&(umenu->gicon));
+		g_free (umenu->text);
+		g_free (umenu);
+	}
+
+	g_list_free (info->user_menu);
+	info->user_menu = NULL;
+}
+
 static void
 setup_an_item (AppletUserMenu *menu,
 	       GtkWidget      *submenu,
@@ -362,8 +385,8 @@ setup_an_item (AppletUserMenu *menu,
 	GtkWidget *image = NULL;
 
 	menu->menuitem = gtk_image_menu_item_new_with_mnemonic (menu->text);
-	if (menu->stock_item && menu->stock_item [0]) {
-		image = gtk_image_new_from_stock (menu->stock_item,
+	if (menu->gicon) {
+		image = gtk_image_new_from_gicon (menu->gicon,
 						  GTK_ICON_SIZE_MENU);
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu->menuitem),
 					       image);
@@ -439,7 +462,7 @@ add_to_submenus (AppletInfo *info,
 	if (s_menu == NULL) {
 		s_menu = g_new0 (AppletUserMenu,1);
 		s_menu->name = g_strdup (t);
-		s_menu->stock_item = NULL;
+		s_menu->gicon = NULL;
 		s_menu->text = g_strdup (_("???"));
 		s_menu->sensitive = TRUE;
 		s_menu->info = info;
@@ -565,7 +588,6 @@ mate_panel_applet_create_menu (AppletInfo *info)
 	}
 
 /* Set up theme and transparency support */
-#if GTK_CHECK_VERSION (3, 0, 0) 
 	GtkWidget *toplevel = gtk_widget_get_toplevel (menu);
 /* Fix any failures of compiz/other wm's to communicate with gtk for transparency */
 	GdkScreen *screen = gtk_widget_get_screen(GTK_WIDGET(toplevel));
@@ -576,7 +598,7 @@ mate_panel_applet_create_menu (AppletInfo *info)
 	context = gtk_widget_get_style_context (GTK_WIDGET(toplevel));
 	gtk_style_context_add_class(context,"gnome-panel-menu-bar");
 	gtk_style_context_add_class(context,"mate-panel-menu-bar");
-#endif
+
 	return menu;
 }
 
@@ -612,9 +634,7 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 {
 	GtkAllocation   allocation;
 	GtkRequisition  requisition;
-#if GTK_CHECK_VERSION(3, 0, 0)
 	GdkDevice      *device;
-#endif
 	GdkScreen      *screen;
 	GtkWidget      *parent;
 	int             menu_x = 0;
@@ -628,21 +648,15 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 
 	screen = gtk_widget_get_screen (applet);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition, NULL);
-#else
-	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-#endif
 
 	gdk_window_get_origin (gtk_widget_get_window (applet), &menu_x, &menu_y);
 #if GTK_CHECK_VERSION(3, 20, 0)
 	device = gdk_seat_get_pointer (gdk_display_get_default_seat (gtk_widget_get_display (applet)));
 	gdk_window_get_device_position (gtk_widget_get_window (applet), device, &pointer_x, &pointer_y, NULL);
-#elif GTK_CHECK_VERSION (3, 0, 0)
+#else
 	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (applet)));
 	gdk_window_get_device_position (gtk_widget_get_window (applet), device, &pointer_x, &pointer_y, NULL);
-#else
-	gtk_widget_get_pointer (applet, &pointer_x, &pointer_y);
 #endif
 	gtk_widget_get_allocation (applet, &allocation);
 
@@ -685,11 +699,7 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 
 	*x = menu_x;
 	*y = menu_y;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	*push_in = FALSE;
-#else
-	*push_in = TRUE;
-#endif
 }
 
 static void
@@ -760,7 +770,6 @@ applet_button_press (GtkWidget      *widget,
 		     GdkEventButton *event,
 		     AppletInfo     *info)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gboolean     applet_locked;
 	PanelWidget *panel_widget;
 
@@ -769,7 +778,6 @@ applet_button_press (GtkWidget      *widget,
 							info->widget);
 
 	if (!applet_locked) mate_panel_applet_set_dnd_enabled (info, TRUE);
-#endif
 
 	if (event->button == 3)
 		return applet_do_popup_menu (widget, event, info);
@@ -781,10 +789,10 @@ static void
 mate_panel_applet_destroy (GtkWidget  *widget,
 		      AppletInfo *info)
 {
-	GList *l;
-
 	g_return_if_fail (info != NULL);
 
+	g_signal_handlers_disconnect_by_data(info->settings,widget);
+
 	info->widget = NULL;
 
 	if (info->settings) {
@@ -827,18 +835,7 @@ mate_panel_applet_destroy (GtkWidget  *widget,
 		info->data_destroy (info->data);
 	info->data = NULL;
 
-	for (l = info->user_menu; l != NULL; l = l->next) {
-		AppletUserMenu *umenu = l->data;
-
-		g_free (umenu->name);
-		g_free (umenu->stock_item);
-		g_free (umenu->text);
-
-		g_free (umenu);
-	}
-
-	g_list_free (info->user_menu);
-	info->user_menu = NULL;
+	mate_panel_applet_clear_user_menu (info);
 
 	g_free (info->id);
 	info->id = NULL;
