@@ -44,6 +44,9 @@
 #include "panel-icon-names.h"
 #include "panel-schemas.h"
 
+static gboolean
+launcher_properties_enabled (void);
+
 static GdkScreen *
 launcher_get_screen (Launcher *launcher)
 {
@@ -128,27 +131,26 @@ launch_url (Launcher *launcher)
 
 void
 launcher_launch (Launcher  *launcher,
-		 GtkWidget *widget)
+		 const gchar *action)
 {
 	char *type;
 
 	g_return_if_fail (launcher != NULL);
 	g_return_if_fail (launcher->key_file != NULL);
 
-	if (panel_global_config_get_enable_animations ())
-		xstuff_zoom_animate (widget,
-				     button_widget_get_pixbuf (BUTTON_WIDGET (widget)),
-				     button_widget_get_orientation (BUTTON_WIDGET (widget)),
-				     NULL);
-	
-	type = panel_key_file_get_string (launcher->key_file, "Type");
+	if (action == NULL) {
+		type = panel_key_file_get_string (launcher->key_file, "Type");
+	} else {
+		type = NULL;
+	}
+
 	if (type && !strcmp (type, "Link"))
 		launch_url (launcher);
 	else {
 		GError *error = NULL;
 
 		panel_launch_key_file (launcher->key_file, NULL,
-				       launcher_get_screen (launcher), &error);
+				       launcher_get_screen (launcher), action, &error);
 		if (error) {
 			GtkWidget *error_dialog;
 
@@ -164,24 +166,6 @@ launcher_launch (Launcher  *launcher,
 		}
 	}
 	g_free (type);
-	
-	if (panel_global_config_get_drawer_auto_close ()) {
-		PanelToplevel *toplevel;
-		PanelToplevel *parent;
-
-		toplevel = PANEL_WIDGET (gtk_widget_get_parent (launcher->button))->toplevel;
-
-		if (panel_toplevel_get_is_attached (toplevel)) {
-			parent = panel_toplevel_get_attach_toplevel (toplevel);
-
-			while (panel_toplevel_get_is_attached (parent)) {
-				toplevel = parent;
-				parent = panel_toplevel_get_attach_toplevel (toplevel);
-			}
-
-			panel_toplevel_hide (toplevel, FALSE, -1);
-		}
-	}
 }
 
 static void
@@ -199,11 +183,15 @@ drag_data_received_cb (GtkWidget        *widget,
 	int      i;
 	GList   *file_list;
 
-	if (panel_global_config_get_enable_animations ())
+	if (panel_global_config_get_enable_animations ()) {
+		GdkPixbuf *pixbuf;
+		pixbuf = button_widget_get_pixbuf (BUTTON_WIDGET (widget));
 		xstuff_zoom_animate (widget,
-				     button_widget_get_pixbuf (BUTTON_WIDGET (widget)),
+				     pixbuf,
 				     button_widget_get_orientation (BUTTON_WIDGET (widget)),
 				     NULL);
+		g_object_unref (pixbuf);
+	}
 	
 	file_list = NULL;
 	uris = g_uri_list_extract_uris ((const char *) gtk_selection_data_get_data (selection_data));
@@ -212,7 +200,7 @@ drag_data_received_cb (GtkWidget        *widget,
 	file_list = g_list_reverse (file_list);
 
 	panel_launch_key_file (launcher->key_file, file_list,
-			       launcher_get_screen (launcher), &error);
+			       launcher_get_screen (launcher), NULL, &error);
 
 	g_list_free (file_list);
 	g_strfreev (uris);
@@ -378,7 +366,7 @@ enum {
 };
 
 
-static void  
+static void
 drag_data_get_cb (GtkWidget        *widget,
 		  GdkDragContext   *context,
 		  GtkSelectionData *selection_data,
@@ -387,7 +375,7 @@ drag_data_get_cb (GtkWidget        *widget,
 		  Launcher         *launcher)
 {
 	char *location;
-	
+
 	g_return_if_fail (launcher != NULL);
 
 	location = launcher->location;
@@ -409,6 +397,41 @@ drag_data_get_cb (GtkWidget        *widget,
 
 }
 
+static void
+clicked_cb (Launcher  *launcher,
+		  GtkWidget        *widget)
+{
+	if (panel_global_config_get_enable_animations ()) {
+		GdkPixbuf *pixbuf;
+		pixbuf = button_widget_get_pixbuf (BUTTON_WIDGET (widget));
+		xstuff_zoom_animate (widget,
+				     pixbuf,
+				     button_widget_get_orientation (BUTTON_WIDGET (widget)),
+				     NULL);
+		g_object_unref (pixbuf);
+	}
+
+	launcher_launch (launcher, NULL);
+
+	if (panel_global_config_get_drawer_auto_close ()) {
+		PanelToplevel *toplevel;
+		PanelToplevel *parent;
+
+		toplevel = PANEL_WIDGET (gtk_widget_get_parent (launcher->button))->toplevel;
+
+		if (panel_toplevel_get_is_attached (toplevel)) {
+			parent = panel_toplevel_get_attach_toplevel (toplevel);
+
+			while (panel_toplevel_get_is_attached (parent)) {
+				toplevel = parent;
+				parent = panel_toplevel_get_attach_toplevel (toplevel);
+			}
+
+			panel_toplevel_hide (toplevel, FALSE, -1);
+		}
+	}
+}
+
 static Launcher *
 create_launcher (const char *location)
 {
@@ -507,7 +530,7 @@ create_launcher (const char *location)
 	g_signal_connect (launcher->button, "drag_leave",
 			   G_CALLBACK (drag_leave_cb), launcher);
 	g_signal_connect_swapped (launcher->button, "clicked",
-				  G_CALLBACK (launcher_launch), launcher);
+				  G_CALLBACK (clicked_cb), launcher);
 
 	launcher->destroy_handler =
 			g_signal_connect (launcher->button, "destroy",
@@ -517,6 +540,37 @@ create_launcher (const char *location)
 	return launcher;
 }
 
+#if GLIB_CHECK_VERSION (2, 38, 0)
+static void
+setup_actions (Launcher *launcher)
+{
+	GDesktopAppInfo     *app_info;
+	const gchar * const *actions;
+	const gchar * const *ptr;
+
+	app_info = g_desktop_app_info_new_from_keyfile (launcher->key_file);
+	if (app_info == NULL)
+		return;
+
+	actions = g_desktop_app_info_list_actions (app_info);
+	ptr = actions;
+	for(; *ptr != NULL; ptr++) {
+		const gchar *action = *ptr;
+		gchar *callback = g_strdup_printf("launch-action_%s", action);
+		gchar *action_name = g_desktop_app_info_get_action_name (app_info, action);
+		mate_panel_applet_add_callback (launcher->info,
+						callback,
+						NULL,
+						action_name,
+						NULL);
+		g_free (callback);
+		g_free (action_name);
+	}
+
+	g_object_unref (app_info);
+}
+#endif
+
 static void
 setup_button (Launcher *launcher)
 {
@@ -525,9 +579,27 @@ setup_button (Launcher *launcher)
 	char *str;
 	char *icon;
 	char *unescaped_str;
-	
+
 	g_return_if_fail (launcher != NULL);
 
+	mate_panel_applet_clear_user_menu (launcher->info);
+
+	mate_panel_applet_add_callback (launcher->info,
+					"launch",
+					"system-run",
+					_("_Launch"),
+					NULL);
+
+#if GLIB_CHECK_VERSION (2, 38, 0)
+	setup_actions (launcher);
+#endif
+
+	mate_panel_applet_add_callback (launcher->info,
+					"properties",
+					"document-properties",
+					_("_Properties"),
+					launcher_properties_enabled);
+
 	name = panel_key_file_get_locale_string (launcher->key_file, "Name");
 	comment = panel_key_file_get_locale_string (launcher->key_file,
 						    "Comment");
@@ -540,8 +612,6 @@ setup_button (Launcher *launcher)
 	else
 		str = g_strdup (comment);
 
-	g_free (name);
-	g_free (comment);
 
 	/* If we can unescape the string, then we probably have an escaped
 	 * string (a location e.g.). If we can't, then it most probably means
@@ -567,9 +637,17 @@ setup_button (Launcher *launcher)
 		icon = NULL;
 	}
 
-	if (!icon)
-		icon = guess_icon_from_exec (button_widget_get_icon_theme (BUTTON_WIDGET (launcher->button)),
-					     launcher->key_file);
+	if (!icon) {
+		gchar *exec;
+		exec = panel_key_file_get_string (launcher->key_file, "Exec");
+		if (exec && exec[0] != '\0') {
+			icon = guess_icon_from_exec (button_widget_get_icon_theme (BUTTON_WIDGET (launcher->button)),
+						     exec);
+		}
+
+		g_free (exec);
+	}
+
 	if (!icon)
 		icon = g_strdup (PANEL_ICON_LAUNCHER);
 
@@ -583,6 +661,7 @@ panel_launcher_find_writable_uri (const char *launcher_location,
 {
 	char *path;
 	char *uri;
+	char *filename;
 
 	if (!launcher_location)
 		return panel_make_unique_desktop_uri (NULL, source);
@@ -594,7 +673,8 @@ panel_launcher_find_writable_uri (const char *launcher_location,
 		return uri;
 	}
 
-	if (panel_launcher_get_filename (launcher_location) != NULL) {
+	filename = panel_launcher_get_filename (launcher_location);
+	if (filename != NULL) {
 		/* we have a file in the user directory. We either have a path
 		 * or an URI */
 		if (g_path_is_absolute (launcher_location))
@@ -604,6 +684,8 @@ panel_launcher_find_writable_uri (const char *launcher_location,
 			return g_strdup (launcher_location);
 	}
 
+	g_free (filename);
+
 	return panel_make_unique_desktop_uri (NULL, source);
 }
 
@@ -662,9 +744,10 @@ launcher_save_uri (PanelDItemEditor *dialog,
 
 	launcher = (Launcher *) data;
 
-	if (launcher)
+	if (launcher) {
 		new_uri = panel_launcher_find_writable_uri (launcher->location,
 							    exec_or_uri);
+	}
 	else
 		new_uri = panel_launcher_find_writable_uri (NULL, exec_or_uri);
 
@@ -685,18 +768,24 @@ launcher_saved (GtkWidget *dialog,
 		Launcher  *launcher)
 {
 	const char  *uri;
+	char  *filename;
+
 	uri = panel_ditem_editor_get_uri (PANEL_DITEM_EDITOR (dialog));
-	if (panel_launcher_get_filename (uri) != NULL)
-		uri = panel_launcher_get_filename (uri);
+	filename = panel_launcher_get_filename(uri);
+	if (filename)
+		uri = filename;
 
 	if (uri && launcher->location && strcmp (uri, launcher->location)) {
-
 		g_settings_set_string (launcher->info->settings, PANEL_OBJECT_LAUNCHER_LOCATION_KEY, uri);
 
 		if (launcher->location)
 			g_free (launcher->location);
+
 		launcher->location = g_strdup (uri);
 	}
+
+	if (filename)
+		g_free (filename);
 }
 
 static void
@@ -786,18 +875,6 @@ load_launcher_applet (const char       *location,
 		return NULL;
 	}
 
-	mate_panel_applet_add_callback (launcher->info,
-				   "launch",
-				   GTK_STOCK_EXECUTE,
-				   _("_Launch"),
-				   NULL);
-
-	mate_panel_applet_add_callback (launcher->info,
-				   "properties",
-				   GTK_STOCK_PROPERTIES,
-				   _("_Properties"),
-				   launcher_properties_enabled);
-
 	panel_widget_set_applet_expandable (panel, GTK_WIDGET (launcher->button), FALSE, TRUE);
 	panel_widget_set_applet_size_constrained (panel, GTK_WIDGET (launcher->button), TRUE);
 
@@ -862,14 +939,20 @@ launcher_new_saved (GtkWidget *dialog,
 	PanelWidget *panel;
 	int          pos;
 	const char  *uri;
+	char        *filename;
 
 	pos = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "pos"));
 	panel = g_object_get_data (G_OBJECT (dialog), "panel");
 
 	uri = panel_ditem_editor_get_uri (PANEL_DITEM_EDITOR (dialog));
-	if (panel_launcher_get_filename (uri) != NULL)
-		uri = panel_launcher_get_filename (uri);
+	filename = panel_launcher_get_filename (uri);
+	if (filename)
+		uri = filename;
+
 	panel_launcher_create (panel->toplevel, pos, uri);
+
+	if (filename)
+		g_free (filename);
 }
 
 void
@@ -971,7 +1054,7 @@ panel_launcher_create_with_id (const char    *toplevel_id,
 	char        *path;
 	char        *id;
 	char        *no_uri;
-	const char  *new_location;
+	char        *new_location;
 
 	g_return_if_fail (location != NULL);
 
@@ -982,7 +1065,7 @@ panel_launcher_create_with_id (const char    *toplevel_id,
 
 	path = g_strdup_printf ("%s%s/", PANEL_OBJECT_PATH, id);
 	settings = g_settings_new_with_path (PANEL_OBJECT_SCHEMA, path);
-	g_free (path); 
+	g_free (path);
 
 	no_uri = NULL;
 	/* if we have an URI, it might contain escaped characters (? : etc)
@@ -994,13 +1077,14 @@ panel_launcher_create_with_id (const char    *toplevel_id,
 
 	new_location = panel_launcher_get_filename (no_uri);
 	if (new_location == NULL)
-		new_location = no_uri;
+		new_location = g_strdup (no_uri);
 
 	g_settings_set_string (settings, PANEL_OBJECT_LAUNCHER_LOCATION_KEY, new_location);
 
 	panel_profile_add_to_list (PANEL_GSETTINGS_OBJECTS, id);
 
 	g_free (no_uri);
+	g_free (new_location);
 	g_free (id);
 	g_object_unref (settings);
 }
