@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
  * Authors:
  *	Vincent Untz <vuntz@gnome.org>
@@ -25,7 +25,7 @@
 #ifndef PANEL_SHOW_H
 #define PANEL_SHOW_H
 
-#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 
 #ifdef __cplusplus
 extern "C" {
