@@ -476,9 +476,13 @@ panel_action_button_finalize (GObject *object)
 {
 	PanelActionButton *button = PANEL_ACTION_BUTTON (object);
 
-	if (button->priv->settings)
+	if (button->priv->settings) {
+		g_signal_handlers_disconnect_by_func (button->priv->settings,
+		                                      G_CALLBACK (panel_action_button_type_changed),
+		                                      button);
 		g_object_unref (button->priv->settings);
-	button->priv->settings = NULL;
+		button->priv->settings = NULL;
+	}
 
 	button->priv->info = NULL;
 	button->priv->type = PANEL_ACTION_NONE;
@@ -643,6 +647,9 @@ void
 panel_action_button_set_type (PanelActionButton     *button,
 			      PanelActionButtonType  type)
 {
+	if (!type)
+		return;
+
 	g_return_if_fail (type > PANEL_ACTION_NONE && type < PANEL_ACTION_LAST);
 
 	if (type == button->priv->type)
