@@ -359,12 +359,8 @@ panel_menu_button_menu_deactivated (PanelMenuButton *button)
 {
 	panel_toplevel_pop_autohide_disabler (button->priv->toplevel);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_unset_state_flags (GTK_WIDGET (button),
 				      GTK_STATE_FLAG_PRELIGHT);
-#else
-	GTK_BUTTON (button)->in_button = FALSE;
-#endif
 	button_widget_set_ignore_leave (BUTTON_WIDGET (button), FALSE);
 }
 
@@ -625,6 +621,9 @@ panel_menu_button_disconnect_from_gsettings (PanelMenuButton *button)
 {
 	if (button->priv->settings)
 	{
+		g_signal_handlers_disconnect_by_func (button->priv->settings,
+		                                      G_CALLBACK (panel_menu_button_gsettings_notify),
+		                                      button);
 		g_object_unref (button->priv->settings);
 		button->priv->settings = NULL;
 	}
@@ -671,7 +670,7 @@ panel_menu_button_load (const char  *menu_path,
 
         if (!panel_lockdown_get_locked_down () &&
             (panel_is_program_in_path ("mozo") ||
-	    panel_is_program_in_path ("matemenu-simple-editor")))
+	    panel_is_program_in_path ("menulibre")))
 		mate_panel_applet_add_callback (info, "edit", NULL,
 					   _("_Edit Menus"), NULL);
 
@@ -990,18 +989,15 @@ panel_menu_button_invoke_menu (PanelMenuButton *button,
 		panel_show_help (screen, "mate-user-guide", "gospanel-37", NULL);
 
 	} else if (!strcmp (callback_name, "edit")) {
-                GError *error = NULL;
 
-		panel_launch_desktop_file_with_fallback ("mozo.desktop",
-							 "mozo",
-							 screen, &error);
-		if (error) {
-			g_error_free (error);
-			panel_launch_desktop_file_with_fallback (
-						"matemenu-simple-editor.desktop",
-						"matemenu-simple-editor",
-						screen, NULL);
-		}
+		if (panel_is_program_in_path ("menulibre"))
+			panel_launch_desktop_file_with_fallback ("menulibre.desktop",
+								 "menulibre",
+								 screen, NULL);
+		else
+			panel_launch_desktop_file_with_fallback ("mozo.desktop",
+								 "mozo",
+								 screen, NULL);
 	}
 }
 
